@@ -187,7 +187,7 @@ namespace Imendio.Blam {
 
 	        if (channel.Name.Equals ("") &&
 		    rssChannel.Title != null) {
-	            channel.Name = rssChannel.Title;
+	            channel.Name = HtmlUtils.StripHtml(rssChannel.Title);
 	            channelUpdated = true;
 	        }
 
@@ -228,7 +228,7 @@ namespace Imendio.Blam {
 
 	            if (channel.Name == "" && 
 		        feed.Title.Content != null) {
-		        channel.Name = feed.Title.Content.Trim();
+		        channel.Name = HtmlUtils.StripHtml(feed.Title.Content.Trim());
 		        channelUpdated = true;
 	            }
 
