@@ -202,7 +202,7 @@ namespace Imendio.Blam {
 	    }
 	}
 
-	private SortFunc itemSortFunc;
+	private SortFunc mItemSortFunc;
 	private int ItemSortFunc(IntPtr a, IntPtr b)
 	{
 	    TreeIter iterA = TreeIter.New(a);
@@ -264,9 +264,9 @@ namespace Imendio.Blam {
 	{
 	    bool reverseEntries;
 
-	    itemSortFunc = new SortFunc (ItemSortFunc);
+	    mItemSortFunc = new SortFunc (ItemSortFunc);
 	    Utils.TreeSetDefaultSortFunc(this.Model.Handle,
-					 itemSortFunc);
+					 mItemSortFunc);
 	    
 	    reverseEntries = Conf.Get (Preference.REVERSE_ENTRIES, false);
 	    SetSortOrder (reverseEntries);
